==> topi-0.0.2-py3-none-any.whl: topi/__init__.py <==
'''
Topi: TIND Object Python Interface

Authors
-------

Michael Hucka <mhucka@caltech.edu> -- Caltech Library

Copyright
---------

Copyright (c) 2020 by the California Institute of Technology.  This code
is open-source software released under a 3-clause BSD license.  Please see the
file "LICENSE" for more information.
'''

# Package metadata ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#  ╭────────────────────── Notice ── Notice ── Notice ─────────────────────╮
#  |    The following values are automatically updated at every release    |
#  |    by the Makefile. Manual changes to these values will be lost.      |
#  ╰────────────────────── Notice ── Notice ── Notice ─────────────────────╯

__version__     = '0.0.2'
__description__ = 'A Python package for getting basic data from a TIND.io server'
__url__         = 'https://github.com/caltechlibrary/topi'
__author__      = 'Michael Hucka'
__email__       = 'mhucka@caltech.edu'
__license__     = 'BSD 3-clause'


# Exports.
# .............................................................................

from .exceptions import TindError, TopiError, NotFound
from .item       import TindItem
from .record     import TindRecord
from .tind       import Tind

__all__ = ['Tind', 'TindRecord', 'TindItem',
           'TindError', 'TopiError', 'NotFound']


# Miscellaneous utilities.
# .............................................................................

def print_version():
    print(f'{__name__} version {__version__}')
    print(f'Authors: {__author__}')
    print(f'URL: {__url__}')
    print(f'License: {__license__}')

==> topi-1.0.0-py3-none-any.whl: topi/__init__.py <==
'''
Topi: TIND Object Python Interface

Authors
-------

Michael Hucka <mhucka@caltech.edu> -- Caltech Library

Copyright
---------

Copyright (c) 2021 by the California Institute of Technology.  This code
is open-source software released under a 3-clause BSD license.  Please see the
file "LICENSE" for more information.
'''

# Package metadata ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#  ╭────────────────────── Notice ── Notice ── Notice ─────────────────────╮
#  |    The following values are automatically updated at every release    |
#  |    by the Makefile. Manual changes to these values will be lost.      |
#  ╰────────────────────── Notice ── Notice ── Notice ─────────────────────╯

__version__     = '1.0.0'
__description__ = 'A Python package for getting basic data from a TIND.io server'
__url__         = 'https://github.com/caltechlibrary/topi'
__author__      = 'Michael Hucka'
__email__       = 'mhucka@caltech.edu'
__license__     = 'BSD 3-clause'


# Exports.
# .............................................................................

from .exceptions import TindError, DataMismatchError, NotFound
from .item       import TindItem
from .record     import TindRecord
from .tind       import Tind

__all__ = ['Tind', 'TindRecord', 'TindItem',
           'TindError', 'DataMismatchError', 'NotFound']


# Miscellaneous utilities.
# .............................................................................

def print_version():
    print(f'{__name__} version {__version__}')
    print(f'Authors: {__author__}')
    print(f'URL: {__url__}')
    print(f'License: {__license__}')
